# DRV Processes (Decision with Reduction of Variability).


[![Build Status](https://travis-ci.org/leliel12/sc_drv.svg?branch=master)](https://travis-ci.org/leliel12/sc_drv)

DRV processes developed on top of [Scikit-Criteria](http://scikit-criteria.org).

DRV processes have been developed to support Group Decision
Making. They are applicable to the cases in which
all members of the group operate in the same organization and, therefore,
they must share organizational values, knowledge and preferences.
Assumes that it is necessary to generate agreement on the preferences of
group members.

## Documentation

- ~~[Instalation]()~~
- [Tutorial](notebooks/tutorial.ipynb)

## Authors

-   Juan B. Cabral ([IATE-OAC-CONICET](https://iate.oac.uncor.edu),
    [FCEIA-UNR](https://web.fceia.unr.edu.ar/es/)) <jbc.develop@gmail.com>
-   Nadia A. Luczywo ([LIMI-FCEFyN-UNC](http://www.portal.efn.uncor.edu),
    [FCE-UNC](http://www.eco.unc.edu.ar/),
    [SECyT-UNC](https://www.unc.edu.ar/ciencia-y-tecnolog%C3%ADa/))
    <nluczywo@gmail.com>
-   José L. Zanazzi ([LIMI-FCEFyN-UNC](http://www.portal.efn.uncor.edu))
    <jl.zanazzi@gmail.com>


## References

-   Zanazzi, J. L., Gomes, L. F. A. M., & Dimitroff, M. (2014). Group decision
    making applied to preventive maintenance systems. Pesquisa Operacional,
    34(1), 91-105.
-   Cabral, J. B., Luczywo, N. A., & Zanazzi, J. L. (2016). Scikit-Criteria:
    colección de métodos de análisis multi-criterio integrado al stack
    científico de Python. In XIV Simposio Argentino de Investigación Operativa
    (SIO 2016)-JAIIO 45 (Tres de Febrero, 2016).
